==> xlniuxdata-vipgame-1.0.65-20161208.112311-45-sources.jar: com/xunlei/niux/data/vipgame/vo/GameXmlMeta.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;


/**
 * 生成游戏xml文件的元数据
 * @author lisu
 * 2013-04-16
 */
@Table(tableName="gamexmlmeta",pkFieldName="seqid",pkFieldAssign=false)
public class GameXmlMeta {

	
	private Long seqid;
	private String gameid;
	private String simpleName;
	private String newgameid;
	private String privateKey;
	private String publicKey;
	private String databaseName;
	private String filePath;
	private Boolean adultCheckFlag;
	private Boolean checkRegisterTimeFlag;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String ext1;
	private String ext2;
	private Boolean isWeiDuan;
	private Boolean isOnlineInterface;
	private Boolean isLevelInterface;
	private Boolean isRank;
	private String roleurl;
	private String onlineurl;
	private String rankurl;
	private String rolekey;
	private String onlinekey;
	private String rankkey;
	private Boolean defaultQuery;
	private Boolean openQueryRoleName;
	private String loginKey;
	private String totalConsumeUrl;
	private String totalConsumeKey;
	private String detailConsumeUrl;
	private String detailConsumeKey;
	private String giftDeailUrl;
	private String giftDeailKey;
	private String gamesendvipkey;
	private String type_1;
	private String type_2;
	private String type_3;
	@Exclude
	private String dsName;

	public String getDsName() {
		return dsName;
	}

	public void setDsName(String dsName) {
		this.dsName = dsName;
	}

	public String getGamesendvipkey() {
		return gamesendvipkey;
	}
	public void setGamesendvipkey(String gamesendvipkey) {
		this.gamesendvipkey = gamesendvipkey;
	}
	public String getType_1() {
		return type_1;
	}
	public void setType_1(String type_1) {
		this.type_1 = type_1;
	}
	public String getType_2() {
		return type_2;
	}
	public void setType_2(String type_2) {
		this.type_2 = type_2;
	}
	public String getType_3() {
		return type_3;
	}
	public void setType_3(String type_3) {
		this.type_3 = type_3;
	}
	public String getTotalConsumeUrl() {
		return totalConsumeUrl;
	}
	public void setTotalConsumeUrl(String totalConsumeUrl) {
		this.totalConsumeUrl = totalConsumeUrl;
	}
	public String getTotalConsumeKey() {
		return totalConsumeKey;
	}
	public void setTotalConsumeKey(String totalConsumeKey) {
		this.totalConsumeKey = totalConsumeKey;
	}
	public String getDetailConsumeUrl() {
		return detailConsumeUrl;
	}
	public void setDetailConsumeUrl(String detailConsumeUrl) {
		this.detailConsumeUrl = detailConsumeUrl;
	}
	public String getDetailConsumeKey() {
		return detailConsumeKey;
	}
	public void setDetailConsumeKey(String detailConsumeKey) {
		this.detailConsumeKey = detailConsumeKey;
	}
	public String getGiftDeailUrl() {
		return giftDeailUrl;
	}
	public void setGiftDeailUrl(String giftDeailUrl) {
		this.giftDeailUrl = giftDeailUrl;
	}
	public String getGiftDeailKey() {
		return giftDeailKey;
	}
	public void setGiftDeailKey(String giftDeailKey) {
		this.giftDeailKey = giftDeailKey;
	}
	public String getLoginKey() {
		return loginKey;
	}
	public void setLoginKey(String loginKey) {
		this.loginKey = loginKey;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getPublicKey() {
		return publicKey;
	}
	public void setPublicKey(String publicKey) {
		this.publicKey = publicKey;
	}
	public String getDatabaseName() {
		return databaseName;
	}
	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public Boolean getAdultCheckFlag() {
		return adultCheckFlag;
	}
	public void setAdultCheckFlag(Boolean adultCheckFlag) {
		this.adultCheckFlag = adultCheckFlag;
	}
	public Boolean getCheckRegisterTimeFlag() {
		return checkRegisterTimeFlag;
	}
	public void setCheckRegisterTimeFlag(Boolean checkRegisterTimeFlag) {
		this.checkRegisterTimeFlag = checkRegisterTimeFlag;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getExt2() {
		return ext2;
	}
	public void setExt2(String ext2) {
		this.ext2 = ext2;
	}
	public Boolean getIsRank() {
		return isRank;
	}
	public void setIsRank(Boolean isRank) {
		this.isRank = isRank;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public String getRoleurl() {
		return roleurl;
	}
	public void setRoleurl(String roleurl) {
		this.roleurl = roleurl;
	}
	public String getRolekey() {
		return rolekey;
	}
	public void setRolekey(String rolekey) {
		this.rolekey = rolekey;
	}
	public String getOnlinekey() {
		return onlinekey;
	}
	public void setOnlinekey(String onlinekey) {
		this.onlinekey = onlinekey;
	}
	public Boolean getDefaultQuery() {
		return defaultQuery;
	}
	public void setDefaultQuery(Boolean defaultQuery) {
		this.defaultQuery = defaultQuery;
	}
	public Boolean getOpenQueryRoleName() {
		return openQueryRoleName;
	}
	public void setOpenQueryRoleName(Boolean openQueryRoleName) {
		this.openQueryRoleName = openQueryRoleName;
	}
	public String getNewgameid() {
		return newgameid;
	}
	public void setNewgameid(String newgameid) {
		this.newgameid = newgameid;
	}
	public String getPrivateKey() {
		return privateKey;
	}
	public void setPrivateKey(String privateKey) {
		this.privateKey = privateKey;
	}
	public Boolean getIsWeiDuan() {
		return isWeiDuan;
	}
	public void setIsWeiDuan(Boolean isWeiDuan) {
		this.isWeiDuan = isWeiDuan;
	}
	public Boolean getIsOnlineInterface() {
		return isOnlineInterface;
	}
	public void setIsOnlineInterface(Boolean isOnlineInterface) {
		this.isOnlineInterface = isOnlineInterface;
	}
	public Boolean getIsLevelInterface() {
		return isLevelInterface;
	}
	public void setIsLevelInterface(Boolean isLevelInterface) {
		this.isLevelInterface = isLevelInterface;
	}
	public String getFilePath() {
		return filePath;
	}
	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}
	public String getOnlineurl() {
		return onlineurl;
	}
	public void setOnlineurl(String onlineurl) {
		this.onlineurl = onlineurl;
	}
	public String getSimpleName() {
		return simpleName;
	}
	public void setSimpleName(String simpleName) {
		this.simpleName = simpleName;
	}
	public String getRankurl() {
		return rankurl;
	}
	public void setRankurl(String rankurl) {
		this.rankurl = rankurl;
	}
	public String getRankkey() {
		return rankkey;
	}
	public void setRankkey(String rankkey) {
		this.rankkey = rankkey;
	}
}

==> xlniuxdata-vipgame-1.0.65-20170407.023208-71-sources.jar: com/xunlei/niux/data/vipgame/vo/GameXmlMeta.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;


/**
 * 生成游戏xml文件的元数据
 * @author lisu
 * 2013-04-16
 */
@Table(tableName="gamexmlmeta",pkFieldName="seqid",pkFieldAssign=false)
public class GameXmlMeta {

	
	private Long seqid;
	private String gameid;
	private String simpleName;
	private String newgameid;
	private String privateKey;
	private String publicKey;
	private String databaseName;
	private String filePath;
	private Boolean adultCheckFlag;
	private Boolean checkRegisterTimeFlag;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String ext1;
	private String ext2;
	private Boolean isWeiDuan;
	private Boolean isOnlineInterface;
	private Boolean isLevelInterface;
	private Boolean isRank;
	private String roleurl;
	private String onlineurl;
	private String rankurl;
	private String rolekey;
	private String onlinekey;
	private String rankkey;
	private Boolean defaultQuery;
	private Boolean openQueryRoleName;
	private String loginKey;
	private String totalConsumeUrl;
	private String totalConsumeKey;
	private String detailConsumeUrl;
	private String detailConsumeKey;
	private String giftDeailUrl;
	private String giftDeailKey;
	private String gamesendvipkey;
	private String type_1;
	private String type_2;
	private String type_3;
	@Exclude
	private String dsName;
	@Exclude
	private String isNewDb;

	public String getIsNewDb() {
		return isNewDb;
	}

	public void setIsNewDb(String isNewDb) {
		this.isNewDb = isNewDb;
	}

	public String getDsName() {
		return dsName;
	}

	public void setDsName(String dsName) {
		this.dsName = dsName;
	}

	public String getGamesendvipkey() {
		return gamesendvipkey;
	}
	public void setGamesendvipkey(String gamesendvipkey) {
		this.gamesendvipkey = gamesendvipkey;
	}
	public String getType_1() {
		return type_1;
	}
	public void setType_1(String type_1) {
		this.type_1 = type_1;
	}
	public String getType_2() {
		return type_2;
	}
	public void setType_2(String type_2) {
		this.type_2 = type_2;
	}
	public String getType_3() {
		return type_3;
	}
	public void setType_3(String type_3) {
		this.type_3 = type_3;
	}
	public String getTotalConsumeUrl() {
		return totalConsumeUrl;
	}
	public void setTotalConsumeUrl(String totalConsumeUrl) {
		this.totalConsumeUrl = totalConsumeUrl;
	}
	public String getTotalConsumeKey() {
		return totalConsumeKey;
	}
	public void setTotalConsumeKey(String totalConsumeKey) {
		this.totalConsumeKey = totalConsumeKey;
	}
	public String getDetailConsumeUrl() {
		return detailConsumeUrl;
	}
	public void setDetailConsumeUrl(String detailConsumeUrl) {
		this.detailConsumeUrl = detailConsumeUrl;
	}
	public String getDetailConsumeKey() {
		return detailConsumeKey;
	}
	public void setDetailConsumeKey(String detailConsumeKey) {
		this.detailConsumeKey = detailConsumeKey;
	}
	public String getGiftDeailUrl() {
		return giftDeailUrl;
	}
	public void setGiftDeailUrl(String giftDeailUrl) {
		this.giftDeailUrl = giftDeailUrl;
	}
	public String getGiftDeailKey() {
		return giftDeailKey;
	}
	public void setGiftDeailKey(String giftDeailKey) {
		this.giftDeailKey = giftDeailKey;
	}
	public String getLoginKey() {
		return loginKey;
	}
	public void setLoginKey(String loginKey) {
		this.loginKey = loginKey;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getPublicKey() {
		return publicKey;
	}
	public void setPublicKey(String publicKey) {
		this.publicKey = publicKey;
	}
	public String getDatabaseName() {
		return databaseName;
	}
	public void setDatabaseName(String databaseName) {
		this.databaseName = databaseName;
	}

	public Boolean getAdultCheckFlag() {
		return adultCheckFlag;
	}
	public void setAdultCheckFlag(Boolean adultCheckFlag) {
		this.adultCheckFlag = adultCheckFlag;
	}
	public Boolean getCheckRegisterTimeFlag() {
		return checkRegisterTimeFlag;
	}
	public void setCheckRegisterTimeFlag(Boolean checkRegisterTimeFlag) {
		this.checkRegisterTimeFlag = checkRegisterTimeFlag;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getExt2() {
		return ext2;
	}
	public void setExt2(String ext2) {
		this.ext2 = ext2;
	}
	public Boolean getIsRank() {
		return isRank;
	}
	public void setIsRank(Boolean isRank) {
		this.isRank = isRank;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public String getRoleurl() {
		return roleurl;
	}
	public void setRoleurl(String roleurl) {
		this.roleurl = roleurl;
	}
	public String getRolekey() {
		return rolekey;
	}
	public void setRolekey(String rolekey) {
		this.rolekey = rolekey;
	}
	public String getOnlinekey() {
		return onlinekey;
	}
	public void setOnlinekey(String onlinekey) {
		this.onlinekey = onlinekey;
	}
	public Boolean getDefaultQuery() {
		return defaultQuery;
	}
	public void setDefaultQuery(Boolean defaultQuery) {
		this.defaultQuery = defaultQuery;
	}
	public Boolean getOpenQueryRoleName() {
		return openQueryRoleName;
	}
	public void setOpenQueryRoleName(Boolean openQueryRoleName) {
		this.openQueryRoleName = openQueryRoleName;
	}
	public String getNewgameid() {
		return newgameid;
	}
	public void setNewgameid(String newgameid) {
		this.newgameid = newgameid;
	}
	public String getPrivateKey() {
		return privateKey;
	}
	public void setPrivateKey(String privateKey) {
		this.privateKey = privateKey;
	}
	public Boolean getIsWeiDuan() {
		return isWeiDuan;
	}
	public void setIsWeiDuan(Boolean isWeiDuan) {
		this.isWeiDuan = isWeiDuan;
	}
	public Boolean getIsOnlineInterface() {
		return isOnlineInterface;
	}
	public void setIsOnlineInterface(Boolean isOnlineInterface) {
		this.isOnlineInterface = isOnlineInterface;
	}
	public Boolean getIsLevelInterface() {
		return isLevelInterface;
	}
	public void setIsLevelInterface(Boolean isLevelInterface) {
		this.isLevelInterface = isLevelInterface;
	}
	public String getFilePath() {
		return filePath;
	}
	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}
	public String getOnlineurl() {
		return onlineurl;
	}
	public void setOnlineurl(String onlineurl) {
		this.onlineurl = onlineurl;
	}
	public String getSimpleName() {
		return simpleName;
	}
	public void setSimpleName(String simpleName) {
		this.simpleName = simpleName;
	}
	public String getRankurl() {
		return rankurl;
	}
	public void setRankurl(String rankurl) {
		this.rankurl = rankurl;
	}
	public String getRankkey() {
		return rankkey;
	}
	public void setRankkey(String rankkey) {
		this.rankkey = rankkey;
	}
}
